#!/usr/bin/env bash

if [ $# -lt 1 ]; then
  echo "usage: $0 DOWNLOAD_DIR"
  exit 1
fi

DOWNLOAD_DIR="$1"

mkdir -p ${DOWNLOAD_DIR}/dune
cd ${DOWNLOAD_DIR}/dune

CORE_MODULES=("dune-common" "dune-geometry" "dune-grid" "dune-istl" "dune-localfunctions")
STAGING_MODULES=("dune-functions" "dune-typetree" "dune-uggrid")
EXTENSIONS_MODULES=("dune-alugrid" "dune-spgrid" "dune-foamgrid")

for MOD in ${CORE_MODULES[*]}; do
  git clone https://gitlab.dune-project.org/core/${MOD}.git --branch releases/2.6 --single-branch
done

for MOD in ${STAGING_MODULES[*]}; do
  git clone https://gitlab.dune-project.org/staging/${MOD}.git --branch releases/2.6 --single-branch
done

for MOD in ${EXTENSIONS_MODULES[*]}; do
  git clone https://gitlab.dune-project.org/extensions/${MOD}.git --branch releases/2.6 --single-branch
done

echo ""
echo "=============================================================="
echo "To build all dune modules run the commands...                 "
echo "  DUNE_CONTROL_PATH=${DOWNLOAD_DIR}/dune dunecontrol configure"
echo "  DUNE_CONTROL_PATH=${DOWNLOAD_DIR}/dune dunecontrol make -j4 "
echo "=============================================================="